using System;
using System.Globalization;
using System.Text;
using System.Text.RegularExpressions;
using System.Threading;
using System.Web;

namespace Singular
{
	public static class TextHelper
	{
		#region Seperate

		/// <summary>
		/// Returns a string with a space between each word.
		/// </summary>
		/// <param name="casedWord"></param>
		/// <returns></returns>
		public static string Separate( string casedWord )
		{
			return Separate( casedWord, " " );
		}
		
		/// <summary>
		/// Returns a string with the seperator between each word.
		/// </summary>
		/// <param name="casedWord"></param>
		/// <param name="separator"></param>
		/// <returns></returns>
		public static string Separate( string casedWord, string separator )
		{
			StringBuilder result = new StringBuilder();
			for( int i = 0, length = casedWord.Length; i < length; i++ )
			{
				if( i > 0 && i < length - 1 && char.IsUpper( casedWord[ i ] ) && !char.IsUpper( casedWord[ i - 1 ] ) )
				{
					result.Append( separator );
				}
				result.Append( casedWord[ i ] );
			}
			return result.ToString();
		}

		#endregion

		#region Hyphenate

		/// <summary>
		/// Returns a string with a hyphen between each word.
		/// </summary>
		/// <param name="casedWord"></param>
		/// <returns></returns>
		public static string Hyphenate( string casedWord )
		{
			return Separate( casedWord, "-" );
		}

		#endregion

		#region Coalesce

		/// <summary>
		/// Returns the first non-empty string in the list
		/// </summary>
		/// <param name="args"></param>
		/// <returns></returns>
		public static string Coalesce( params string[] args )
		{
			string value = string.Empty;
			foreach( string arg in args )
			{
				if( !string.IsNullOrEmpty( arg ) )
				{
					value = arg;
					break;
				}
			}
			return value;
		}

		#endregion

	}
} 

