using System;
using System.Collections.Generic;
using System.Text;

namespace Singular.Web.UI.Controls
{
	public class ScriptList : List<Script>
	{
		#region Private Variables
		
		#endregion
		
		#region Contructors
		
		#endregion
		
		#region Properties
		
		/// <summary>
		/// Gets the first item of the list
		/// </summary>
		public Script First
		{
			get{ return Count > 0 ? this[ 0 ] : null; }
		}
		
		/// <summary>
		/// Gets the last item of the list
		/// </summary>
		public Script Last
		{
			get{ return Count > 0 ? this[ Count - 1 ] : null; }
		}
		
		#endregion
		
		#region Methods

		#region Add

		/// <summary>
		/// Add external scripts
		/// </summary>
		/// <param name="scripts"></param>
		public void Add( params string[] scripts )
		{
			foreach( string src in scripts )
				Add( src, true );
		}

		/// <summary>
		/// Add a script
		/// </summary>
		/// <param name="content"></param>
		/// <param name="external"></param>
		public void Add( string content, bool external )
		{
			Add( new Script( content, external ) );
		}

		#endregion

		#region Contains

		/// <summary />
		public bool Contains( string key )
		{
			return IndexOf( key ) != -1;
		}

		#endregion

		#region IndexOf

		/// <summary />
		public int IndexOf( string key )
		{
			Predicate<Script> criteria = delegate( Script item ) { return item.Key == key; };
			return FindIndex( criteria );
		}

		#endregion

		#region Find
		
		/// <summary />
		public Script Find( string key )
		{
			Predicate<Script> criteria = delegate( Script item ) { return item.Key == key; };
			return Find( criteria );
		}
		
		#endregion
		
		#region FindBy...
		
		/// <summary />
		public ScriptList FindByKey( string key )
		{
			Predicate<Script> criteria = delegate( Script item ){ return item.Key == key; };
			return FindAll( criteria );
		}
		
		#endregion
		
		#region FindAll
		
		/// <summary>
		/// 
		/// </summary>
		/// <param name="match"></param>
		/// <returns></returns>
		public new ScriptList FindAll( Predicate<Script> match )
		{
			if( null == match )
			{
				throw new ArgumentNullException( "match cannot be null." );
			}

			ScriptList found = new ScriptList();
			Action<Script> action = delegate( Script item )
			{ 
				if( match( item ) )
					found.Add( item ); 
			};
			ForEach( action );
			return found;
		}
		
		#endregion
		
		#endregion
	}
}

