using System;
using System.Collections.Generic;
using System.Text;
using System.Web.UI;

namespace Singular.Web.UI.Controls
{
	public class Stylesheet : Control, IComparable, IComparable<Stylesheet>, IComparable<string>
	{
		public const string DefaultContentType = "text/css";

		#region Private Variables

		string _key;
		string _content;
		bool _external;
		string _mediaType;
		bool _compress = false;
		bool _minify = false;

		#endregion

		#region Constructors

		/// <summary>
		/// 
		/// </summary>
		public Stylesheet()
			: this( string.Empty, false )
		{
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="content"></param>
		/// <param name="external"></param>
		public Stylesheet( string content, bool external )
			: this( null, content, null, external )
		{
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="content"></param>
		/// <param name="mediaType"></param>
		/// <param name="external"></param>
		public Stylesheet( string content, string mediaType, bool external )
			: this( null, content, mediaType, external )
		{

		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="key"></param>
		/// <param name="content"></param>
		/// <param name="mediaType"></param>
		/// <param name="external"></param>
		public Stylesheet( string key, string content, string mediaType, bool external )
		{
			_key = key;
			_content = content;
			_mediaType = mediaType;
			_external = external;
		}

		#endregion

		#region Properties

		/// <summary>
		/// The key that the script should be known as
		/// </summary>
		public string Key
		{
			get { return _key ?? _content; }
			set { _key = value; }
		}

		/// <summary>
		/// The script's external src or actual content
		/// </summary>
		public string Content
		{
			get { return _content; }
			set { _content = value; }
		}

		/// <summary>
		/// Sets the Content to the given value, and ensures the control is 
		/// marked as having an external source
		/// </summary>
		public string Src
		{
			get { return _external ? _content : null; }
			set
			{
				_content = value;
				_external = true;
			}
		}

		/// <summary>
		/// Whether the script is external or not
		/// </summary>
		public bool External
		{
			get { return _external; }
			set { _external = value; }
		}

		/// <summary>
		/// The media type of the style
		/// </summary>
		public string MediaType
		{
			get { return _mediaType; }
			set { _mediaType = value; }
		}

		/// <summary>
		/// Placeholder for dynamic http compression
		/// </summary>
		public bool Compress
		{
			get { return _compress; }
			set { _compress = value; ; }
		}

		/// <summary>
		/// Placeholder for dynamic text minification
		/// </summary>
		public bool Minify
		{
			get { return _minify; }
			set { _minify = value; ; }
		}

		#endregion

		#region Methods

		#region ToString

		/// <summary>
		/// 
		/// </summary>
		/// <returns></returns>
		public override string ToString()
		{
			return _content;
		}

		#endregion

		#region IComparable Members

		public int CompareTo( object obj )
		{
			if( obj is Stylesheet )
			{
				return CompareTo( (Stylesheet)obj );
			}
			else if( obj is string )
			{
				return CompareTo( (string)obj );
			}

			throw new ArgumentException( "Argument is of the wrong type." );
		}

		#endregion

		#region IComparable<Stylesheet> Members

		public int CompareTo( Stylesheet other )
		{
			return _key.CompareTo( other.Key );
		}

		#endregion

		#region IComparable<string> Members

		public int CompareTo( string other )
		{
			return Key.CompareTo( other );
		}

		#endregion

		#region Render

		/// <summary>
		/// 
		/// </summary>
		/// <param name="writer"></param>
		protected override void Render( HtmlTextWriter writer )
		{
			if( External ) renderCssExternal( writer );
			else renderCssContent( writer );
		}

		#endregion

		#region renderCssContent

		/// <summary>
		/// 
		/// </summary>
		/// <param name="writer"></param>
		void renderCssContent( HtmlTextWriter writer )
		{
			writer.WriteBeginTag( "style" );
			writer.WriteAttribute( "type", DefaultContentType );

			if( !string.IsNullOrEmpty( MediaType ) )
			{
				writer.WriteAttribute( "media", MediaType );
			}

			writer.Write( HtmlTextWriter.TagRightChar );
			writer.Write( Content );
			writer.WriteEndTag( "style" );
		}

		#endregion

		#region renderCssExternal

		/// <summary>
		/// 
		/// </summary>
		/// <param name="writer"></param>
		void renderCssExternal( HtmlTextWriter writer )
		{
			writer.WriteBeginTag( "link" );
			writer.WriteAttribute( "type", DefaultContentType );
			writer.WriteAttribute( "rel", "stylesheet" );
			writer.WriteAttribute( "href", ResolveUrl( Content ) );

			if( !string.IsNullOrEmpty( MediaType ) )
			{
				writer.WriteAttribute( "media", MediaType );
			}

			writer.Write( HtmlTextWriter.TagRightChar );
		}

		#endregion

		#endregion

	}
}

