using System;
using System.Collections.Generic;
using System.Text;

namespace Singular.Web.UI.Controls
{
	public class StylesheetList : List<Stylesheet>
	{
		#region Private Variables
		
		#endregion
		
		#region Contructors
		
		#endregion
		
		#region Properties
		
		/// <summary>
		/// Gets the first item of the list
		/// </summary>
		public Stylesheet First
		{
			get{ return Count > 0 ? this[ 0 ] : null; }
		}
		
		/// <summary>
		/// Gets the last item of the list
		/// </summary>
		public Stylesheet Last
		{
			get{ return Count > 0 ? this[ Count - 1 ] : null; }
		}
		
		#endregion
		
		#region Methods

		#region Add

		/// <summary>
		/// Add external scripts
		/// </summary>
		/// <param name="scripts"></param>
		public void Add( params string[] stylesheets )
		{
			foreach( string src in stylesheets )
				Add( src, true );
		}

		/// <summary>
		/// Add a script
		/// </summary>
		/// <param name="content"></param>
		/// <param name="external"></param>
		public void Add( string content, bool external )
		{
			Add( new Stylesheet( content, external ) );
		}

		#endregion

		#region Contains

		/// <summary />
		public bool Contains( string key )
		{
			return IndexOf( key ) != -1;
		}

		#endregion

		#region IndexOf

		/// <summary />
		public int IndexOf( string key )
		{
			Predicate<Stylesheet> criteria = delegate( Stylesheet item ) { return item.Key.Equals( key ); };
			return FindIndex( criteria );
		}

		#endregion

		#region Find
		
		/// <summary />
		public Stylesheet Find( string key )
		{
			Predicate<Stylesheet> criteria = delegate( Stylesheet item ) { return item.Key.Equals( key ); };
			return Find( criteria );
		}
		
		#endregion
		
		#region FindBy...
		
		/// <summary />
		public StylesheetList FindByKey( string key )
		{
			Predicate<Stylesheet> criteria = delegate( Stylesheet item ){ return item.Key.Equals( key ); };
			return FindAll( criteria );
		}
		
		#endregion
		
		#region FindAll
		
		/// <summary>
		/// 
		/// </summary>
		/// <param name="match"></param>
		/// <returns></returns>
		public new StylesheetList FindAll( Predicate<Stylesheet> match )
		{
			if( null == match )
			{
				throw new ArgumentNullException( "match cannot be null." );
			}

			StylesheetList found = new StylesheetList();
			Action<Stylesheet> action = delegate( Stylesheet item )
			{ 
				if( match( item ) )
					found.Add( item ); 
			};
			ForEach( action );
			return found;
		}
		
		#endregion
		
		#endregion
	}
}

