using System;
using System.Collections.Generic;
using System.Text;

namespace Singular.Web.YUI
{
	public sealed class YuiCss : Singular.Web.UI.Controls.Stylesheet
	{
		#region UrlTemplate

		static class UrlTemplate
		{
			public const string Build = "http://yui.yahooapis.com/{0}/build/{1}/{1}-min.css";
			public const string Asset = "http://yui.yahooapis.com/{0}/build/{1}/assets/{1}.css";
			public const string Aggregate = "http://yui.yahooapis.com/{0}/build/{1}/{1}.css";

			#region GetUrl

			/// <summary>
			/// 
			/// </summary>
			/// <param name="type"></param>
			/// <returns></returns>
			public static string GetUrl( YuiCssType type )
			{
				string template = null;
				switch( type )
				{
					case YuiCssType.ResetFontsGrids:
						template = UrlTemplate.Aggregate;
						break;
					case YuiCssType.Button:
					case YuiCssType.Calendar:
					case YuiCssType.Container:
					case YuiCssType.Datatable:
					case YuiCssType.Logger:
					case YuiCssType.Menu:
					case YuiCssType.Tabview:
						template = UrlTemplate.Asset;
						break;
					default:
						template = UrlTemplate.Build;
						break;
				}
				return template;
			}

			#endregion
		}

		#endregion

		#region Private Variables

		YuiCssType _type;
		string _version;

		#endregion

		#region Constructors

		/// <summary>
		/// 
		/// </summary>
		public YuiCss()
		{
			External = true;
			_version = YuiScript.DefaultVersion;
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="type"></param>
		public YuiCss( YuiCssType type )
			: this()
		{
			_type = type;
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="version"></param>
		/// <param name="type"></param>
		public YuiCss( string version, YuiCssType type )
			: this()
		{
			_version = version;
			_type = type;
		}

		#endregion

		#region Properties

		/// <summary>
		/// 
		/// </summary>
		public YuiCssType Type
		{
			get { return _type; }
			set { _type = value; }
		}

		/// <summary>
		/// 
		/// </summary>
		public string Version
		{
			get { return _version; }
			set { _version = value; }
		}

		#endregion

		#region GetUrl

		/// <summary>
		/// 
		/// </summary>
		/// <returns></returns>
		public string GetUrl()
		{
			return GetUrl( _version, _type );
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="version"></param>
		/// <param name="type"></param>
		/// <returns></returns>
		public static string GetUrl( string version, YuiCssType type )
		{
			return string.Format( UrlTemplate.GetUrl( type ), version, TextHelper.Hyphenate( type.ToString() ).ToLower() );
		}

		#endregion

		#region OnPreRender

		/// <summary>
		/// 
		/// </summary>
		/// <param name="e"></param>
		protected override void OnPreRender( EventArgs e )
		{
			Src = GetUrl();
		}

		#endregion

	}
}
