using System;
using System.Configuration;
using System.Collections.Generic;
using System.Text;

namespace Singular.Web.YUI
{
	public sealed class YuiScript : Singular.Web.UI.Controls.Script
	{
		#region Constants and Helpers

		static class Keys
		{
			const string prefix = "YUI.";
			public const string Version = prefix + "Version";
		}

		static class UrlTemplate
		{
			public const string DefaultVersion = "2.2.0";
			public const string Build = "http://yui.yahooapis.com/{0}/build/{1}/{1}-min.js";
			public const string Aggregate = "http://yui.yahooapis.com/{0}/build/{1}/{1}.js";

			#region GetUrl

			/// <summary>
			/// 
			/// </summary>
			/// <param name="type"></param>
			/// <returns></returns>
			public static string GetUrl( YuiScriptType type )
			{
				string template = null;
				switch( type )
				{
					case YuiScriptType.Utilities:
					case YuiScriptType.YahooDomEvent:
						template = UrlTemplate.Aggregate;
						break;
					default:
						template = UrlTemplate.Build;
						break;
				}
				return template;
			}

			#endregion
		}

		#endregion

		#region Private Variables

		internal static readonly string DefaultVersion;
		YuiScriptType _type;
		string _version;

		#endregion

		#region Constructors

		/// <summary>
		/// 
		/// </summary>
		static YuiScript()
		{
			DefaultVersion = TextHelper.Coalesce( ConfigurationManager.AppSettings[ Keys.Version ], UrlTemplate.DefaultVersion );
		}

		/// <summary>
		/// 
		/// </summary>
		public YuiScript()
		{
			External = true;
			_version = DefaultVersion;
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="type"></param>
		public YuiScript( YuiScriptType type )
			: this()
		{
			_type = type;
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="version"></param>
		/// <param name="type"></param>
		public YuiScript( string version, YuiScriptType type )
			: this()
		{
			_version = version;
			_type = type;
		}

		#endregion

		#region Properties

		/// <summary>
		/// 
		/// </summary>
		public YuiScriptType Type
		{
			get { return _type; }
			set { _type = value; }
		}

		/// <summary>
		/// 
		/// </summary>
		public string Version
		{
			get { return _version; }
			set { _version = value; }
		}

		#endregion

		#region GetUrl

		/// <summary>
		/// 
		/// </summary>
		/// <returns></returns>
		public string GetUrl()
		{
			return GetUrl( _version, _type );
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="version"></param>
		/// <param name="type"></param>
		/// <returns></returns>
		public static string GetUrl( string version, YuiScriptType type )
		{
			return string.Format( UrlTemplate.GetUrl( type ), version, TextHelper.Hyphenate( type.ToString() ).ToLower() );
		}

		#endregion

		#region OnPreRender

		/// <summary>
		/// 
		/// </summary>
		/// <param name="e"></param>
		protected override void OnPreRender( EventArgs e )
		{
			Src = GetUrl();
		}

		#endregion

	}
}
